## infestor

infestor is a cross platform CLI app to claim and create
discounted accounts on the STEEM blockchain.

## Installation

```
$ pip install infestor
```

## Claiming discounted accounts

```
$ infestor claim_account --creator <your_account>
```

## Creating accounts

```
$ infestor create_account --new-account-name <your_new_account> --creator <your_main_account>
```

